.. Camelot documentation master file, created by
   sphinx-quickstart on Thu Jun 11 21:14:38 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _camelotdoc-index:

Welcome to Camelot's documentation!
===================================

:Release: |version|
:Date: |today|
   
.. toctree::
   :maxdepth: 1
   
   news.rst
   
Contents:

.. toctree::
   :maxdepth: 2

   tutorial/index.rst
   doc/index.rst
   api/index.rst
   advanced/index.rst
   cep/index.rst

Support
=======

Community
---------

Community support is available on the `mailing list <http://groups.google.com/group/project-camelot>`_.

Commercial
----------

Commercial support and training is available from Conceptive Engineering, the
main authors of Camelot :

|
| Conceptive Engineering            
| L Van Bauwelstraat 16  
| 2222 Heist-op-den-Berg
| Belgium 
|
| project-camelot@conceptive.be
| http://www.conceptive.be
| VAT BE 0878 169 209
| Fax : +32 3 303 64 41
|

Priority support tickets can be purchased from the `shop <http://www.python-camelot.com/shop.html>`_.
Please contact us for support contracts.

Indices and tables:

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Others:

.. toctree::
   :maxdepth: 2

   Complete Table of Contents <contents.rst>
   license.rst
   copyright.rst
